#include "conn.h"

void hashInit();
void hashDebug();

struct connection *hashFind(struct connid *cid);
struct connection *hashFindAll();
int hashAdd(struct connection *conn);
struct connection *hashDelete(struct connid *cid);
